#ifndef MUNIXMOUNTSURVEILER_H
#define MUNIXMOUNTSURVEILER_H

#include <QObject>
#include <QScopedPointer>

/*!
 * \brief The MUnixMountSurveiler class
 *
 * This class polls /proc/mounts for changes and emits
 * mountsChanged() when that virtual file changed.
 */
class MUnixMountSurveiler : public QObject
{
    Q_OBJECT
    
public:
    explicit MUnixMountSurveiler(QObject *parent = nullptr);
    ~MUnixMountSurveiler();
    
signals:
    /*!
     * \brief mountsChanged
     *
     * connect to this signal to get notified of changed to the mounts
     *
     * \code
     * MUnixMountSurveiler *mountSurveiler = new MUnixMountSurveiler();
     * QObject::connect(mountSurveiler, &MUnixMountSurveiler::mountsChanged, []() { qDebug() << "Mounts changed"; });
     * \endcode
     */
    void mountsChanged();

private:
    class Private;
    QScopedPointer<Private> d_ptr;
};

#endif //MUNIXMOUNTSURVEILER_H
