#ifndef MABOUTDIALOG_H
#define MABOUTDIALOG_H

// Qt
#include <QDialog>
#include <QScopedPointer>
#include <QUrl>

class MAboutDialog : public QDialog
{
    Q_OBJECT

    Q_PROPERTY(QString author READ author WRITE setAuthor NOTIFY authorChanged)
    Q_PROPERTY(QString applicationName READ applicationName WRITE setApplicationName NOTIFY applicationNameChanged)
    Q_PROPERTY(QString applicationVersion READ applicationVersion WRITE setApplicationVersion NOTIFY applicationVersionChanged)
    Q_PROPERTY(QString homepage READ homepage WRITE setHomepage NOTIFY homepageChanged)
    Q_PROPERTY(QString authorsHelpPage READ authorsHelpPage WRITE setAuthorsHelpPage NOTIFY authorsHelpPageChanged)
    Q_PROPERTY(QString licenseHelpPage READ licenseHelpPage WRITE setLicenseHelpPage NOTIFY licenseHelpPageChanged)
    Q_PROPERTY(QUrl updateUrl READ updateUrl WRITE setUpdateUrl NOTIFY updateUrlChanged)
    Q_PROPERTY(QPixmap pixmap READ pixmap WRITE setPixmap NOTIFY pixmapChanged)

public:
    explicit MAboutDialog(QWidget *parent = nullptr);
    ~MAboutDialog();

    QString &author() const;
    QString &applicationName() const;
    QString &applicationVersion() const;
    QString &homepage() const;
    QString &authorsHelpPage() const;
    QString &licenseHelpPage() const;
    QUrl &updateUrl() const;
    QPixmap &pixmap() const;

public slots:
    void setAuthor(const QString &author);
    void setApplicationName(const QString &applicationName);
    void setApplicationVersion(const QString &applicationVersion);
    void setHomepage(const QString &homepage);
    void setAuthorsHelpPage(const QString &authorsHelpPage);
    void setLicenseHelpPage(const QString &licenseHelpPage);

    /*!
     * \brief Sets the url to the JSON document that contains the latest version
     * \param updateUrl
     *
     * Example JSON document:
     * {
     *     "latest" : 1.8
     * }
     */
    void setUpdateUrl(const QUrl &updateUrl);
    void setPixmap(const QPixmap &pixmap);
    void setPixmap(const QIcon &icon);

    void adjustSize();
    void updateLinks();

signals:
    void authorChanged(const QString &author);
    void applicationNameChanged(const QString &applicationName);
    void applicationVersionChanged(const QString &applicationVersion);
    void homepageChanged(const QString &homepage);
    void authorsHelpPageChanged(const QString &authorsHelpPage);
    void licenseHelpPageChanged(const QString &licenseHelpPage);
    void updateUrlChanged(const QUrl &updateUrl);
    void pixmapChanged(const QPixmap &pixmap);

private:
    class Private;
    QScopedPointer<Private> d_ptr;
};

#endif // MABOUTDIALOG_H
