#include "mspinnerpushbutton_p.h"
#include "mspinnerpushbutton.h"

// Qt
#include <QHBoxLayout>
#include <QLabel>

#include <MSpinner>

MSpinnerPushButton::MSpinnerPushButton(QWidget *parent) :
    MSpinnerPushButton(*new MSpinnerPushButtonPrivate, parent)
{

}

MSpinnerPushButton::MSpinnerPushButton(MSpinnerPushButtonPrivate &d_ptr, QWidget *parent) :
    MLayoutPushButton(d_ptr, parent)
{
    Q_D(MSpinnerPushButton);

    setCheckable(true);

    QHBoxLayout *boxLayout = new QHBoxLayout(this);

    uint spinnerSize = sizeHint().height()-4;
    d->spinner = new MSpinner(this);
    d->spinner->setColorize(true);
    d->spinner->setMinimumSize(spinnerSize, spinnerSize);
    d->spinner->setMaximumSize(spinnerSize, spinnerSize);
    boxLayout->addWidget(d->spinner);

    d->label = new QLabel(this);
    d->label->setMargin(1);
    boxLayout->addWidget(d->label);
    setLayout(boxLayout);


    boxLayout->setContentsMargins(6, 2, 5, 2);

    d->spinner->setVisible(isChecked());
    connect(this, &MSpinnerPushButton::toggled, [this, d, boxLayout](bool checked) {
        if (checked) {
            boxLayout->setContentsMargins(6, 2, 5, 2);
        } else {
            boxLayout->setContentsMargins(9+d->spinner->width()/2, 2, 9+d->spinner->width()/2, 2);
        }
        d->spinner->setVisible(checked);
    });
}

MSpinnerPushButton::~MSpinnerPushButton()
{

}

void MSpinnerPushButton::setText(const QString &text)
{
    Q_D(MSpinnerPushButton);
    d->label->setText(text);
    if (isChecked()) {
        layout()->setContentsMargins(6, 2, 5, 2);
    } else {
        layout()->setContentsMargins(9+d->spinner->width()/2, 2, 9+d->spinner->width()/2, 2);
    }
    adjustSize();
}

QString MSpinnerPushButton::text() const
{
    Q_D(const MSpinnerPushButton);
    return d->label->text();
}
