#ifndef PAGER_H
#define PAGER_H

#include <QDialog>
#include <QSharedPointer>
#include <QWizardPage>

class Stash;

namespace Ui {
class Pager;
}

class Pager : public QDialog
{
    Q_OBJECT

public:
    explicit Pager(QSharedPointer<Stash> stash, QWidget *parent = 0);
    explicit Pager(const QString &title, QWidget *parent = 0);
    ~Pager();

signals:
    void pageAdded();

public slots:
    /*!
     * \brief addPage
     * \param wizardPage
     *
     * This adds a page to the pager.
     * Add the page you want to show first, then use insertPage
     * for the remaining pages to ensure correct size when showing.
     */
    void addPage(QWizardPage *wizardPage);

    void insertPage(int index, QWizardPage *wizardPage);
    void selectPage(int pageNr);
    void adjustSize();
    void sidebarToggled(bool showSidebar);
    void reject() override;

private:
    Ui::Pager *ui;
    QSharedPointer<Stash> m_stash;

    QWizardPage *m_firstWidget;
    class MenuListModel;
    class MenuItemDelegate;
};

#endif // PAGER_H
